Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(337)

Unified Diff: chrome/browser/history/thumbnail_database.h

Issue 10917041: Cleanup FaviconSQLHandler::Update (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/thumbnail_database.h
diff --git a/chrome/browser/history/thumbnail_database.h b/chrome/browser/history/thumbnail_database.h
index f32ead1af23911e2d30fab0c7e76a4c7492e30d9..10a8198c9cfc810bbc70a8eff2d00e4358550ed6 100644
--- a/chrome/browser/history/thumbnail_database.h
+++ b/chrome/browser/history/thumbnail_database.h
@@ -149,12 +149,14 @@ class ThumbnailDatabase {
IconType* icon_type,
FaviconSizes* favicon_sizes);
- // Adds favicon with |icon_url| and |icon_type| to the favicon db, returning
- // its id.
- FaviconID AddFavicon(const GURL& icon_url, IconType icon_type);
+ // Adds favicon with |icon_url|, |icon_type| and |favicon_sizes| to the
+ // favicon db, returning its id.
+ FaviconID AddFavicon(const GURL& icon_url,
+ IconType icon_type,
+ const FaviconSizes& favicon_sizes);
// Adds a favicon with a single bitmap. This call is equivalent to calling
- // AddFavicon, SetFaviconSizes, and AddFaviconBitmap.
+ // AddFavicon and AddFaviconBitmap.
FaviconID AddFavicon(const GURL& icon_url,
IconType icon_type,
const FaviconSizes& favicon_sizes,
@@ -202,6 +204,10 @@ class ThumbnailDatabase {
// Returns true if the deletion succeeded.
bool DeleteIconMappings(const GURL& page_url);
+ // Deletes the icon mapping with |mapping_id|.
+ // Returns true if the deletion succeeded.
+ bool DeleteIconMapping(IconMappingID mapping_id);
+
// Checks whether a favicon is used by any URLs in the database.
bool HasMappingFor(FaviconID id);

Powered by Google App Engine
This is Rietveld 408576698